@@ -4,4 +4,4 @@ from .http_aws_blueair import HttpAwsBlueair
 from .util_bootstrap import get_devices, get_aws_devices
 from .device import Device
 from .device_aws import DeviceAws
-from .model_enum import ModelEnum, FeatureEnum
+from .model_enum import ModelEnum
