@@ -1,14 +1,11 @@
 # run with "python3 src/blueair_api/stub.py"
 import logging
 import asyncio
-from threading import Event
 
 from getpass import getpass
 from pathlib import Path
 import sys
 
-# import blueair_api
-
 path_root = Path(__file__).parents[2]
 sys.path.append(str(path_root))
 from src.blueair_api import get_devices, get_aws_devices
@@ -28,16 +25,15 @@ async def testing():
     password = getpass()
     try:
         api, devices = await get_aws_devices(username=username, password=password)
-        await devices[0].refresh()
-        await devices[0].set_child_lock(True)
-        logger.debug(devices[0])
+        for device in devices:
+            await device.refresh()
+            logger.debug(device)
     finally:
         if api:
             await api.cleanup_client_session()
     try:
         api, devices = await get_devices(username=username, password=password)
         for device in devices:
-            await device.post_init()
             await device.refresh()
             logger.debug(device)
     finally:
